============
Installation
============

At the command line::

	$ pip install -e git+https://github.com/jlmadurga/yowsup.git@issue_1181#egg=yowsup
    $ pip install yowsup-celery

At the moment only works with yowsup fork https://github.com/jlmadurga/yowsup.git@issue_1181

